@@ -1,6 +1,3 @@
-import json
-
-
 class PayloadDetail:
     def __init__(
             self,
@@ -28,6 +25,3 @@ class PayloadDetail:
         self.metadata = metadata
         self.sdk = sdk
         self.user = user
-
-    def toJSON(self):
-        return json.dumps(self, default=lambda o: o.__dict__, sort_keys=True, indent=4)
