@@ -45,7 +45,7 @@ with requests.Session() as session:
     def info(message, event_time_required=False):
         installed_packages = [{d.project_name: d.version} for d in pkg_resources.working_set]
         eventTime = datetime.now().strftime("%m/%d/%Y, %H:%M:%S") if event_time_required else None
-        sourceFilePath = str(sys._getframe().f_code)
+        sourceFilePath = str(sys._getframe().f_code.file)
         methodName = str(sys._getframe(1).f_code.co_name)
 
         detail = [
@@ -86,7 +86,7 @@ with requests.Session() as session:
         message = jsonpickle.encode(occurred_error)
         installed_packages = [{d.project_name: d.version} for d in pkg_resources.working_set]
         eventTime = datetime.now().strftime("%m/%d/%Y, %H:%M:%S") if event_time_required else None
-        sourceFilePath = str(sys._getframe().f_code)
+        sourceFilePath = str(sys._getframe().f_code.file)
         methodName = str(sys._getframe(1).f_code.co_name)
 
         detail = [
